@@ -26,6 +26,16 @@ typedef RETSIGTYPE (*SIGNAL_HANDLER)(int);
 # define sigismember(s,n)  ((*(s) & (1 << ((n) - 1))) != 0)
 #endif
 
+/*
+ * Just use sigjmp/longjmp on older machines that
+ * don't have sigsetjmp/siglongjmp.
+ */
+#ifndef HAVE_SIGSETJMP
+# define sigjmp_buf jmp_buf
+# define sigsetjmp(env,mask) setjmp(env)
+# define siglongjmp(env,val) longjmp(env,val)
+#endif
+
 /*
  * prototypes
  */
