@@ -65,7 +65,9 @@ static struct ftable functable[] = {
      { "comp",       TF_COMP,	FT_LS_COMP,	0,		TFL_PUTS },
      { "lit",        TF_STR,	FT_LS_LIT,	0,		TFL_PUTS },
      { "getenv",     TF_STR,	FT_LS_GETENV,	0,		TFL_PUTS },
-     { "profile",    TF_STR,	FT_LS_MFIND,	0,		TFL_PUTS },
+     { "profile",    TF_STR,	FT_LS_CFIND,	0,		TFL_PUTS },
+     { "decodecomp", TF_COMP,	FT_LS_DECODECOMP, 0,		TFL_PUTS },
+     { "decode",     TF_EXPR,	FT_LS_DECODE,	0,		TFL_PUTS },
      { "trim",       TF_EXPR,	FT_LS_TRIM,	0,		0 },
      { "compval",    TF_COMP,	FT_LV_COMP,	0,		TFL_PUTN },
      { "compflag",   TF_COMP,	FT_LV_COMPFLAG,	0,		TFL_PUTN },
