@@ -562,7 +562,13 @@ main (int argc, char **argv)
 		adios (NULL, "unable to fdopen %s", packfile);
 	} else {
 	    hghnum = msgnum = mp->hghmsg;
-	    if (!(mp = folder_realloc (mp, mp->lowoff, mp->hghmsg + nmsgs)))
+	    /*
+	     * Check if we have enough message space for all the new
+	     * messages.  If not, then realloc the folder and add enough
+	     * space for all new messages plus 10 additional slots.
+	     */
+	    if (mp->hghmsg + nmsgs >= mp->hghoff
+		&& !(mp = folder_realloc (mp, mp->lowoff, mp->hghmsg + nmsgs + 10)))
 		adios (NULL, "unable to allocate folder storage");
 	}
 
@@ -674,12 +680,15 @@ main (int argc, char **argv)
 	m_unknown (in);		/* the MAGIC invocation... */
 	hghnum = msgnum = mp->hghmsg;
 	for (i = 0;;) {
-	    if (msgnum >= mp->hghoff) {
-		if (!(mp = folder_realloc (mp, mp->lowoff, mp->hghoff + MAXFOLDER))) {
-		    advise (NULL, "unable to allocate folder storage");
-		    i = NOTOK;
-		    break;
-		}
+	    /*
+	     * Check if we need to allocate more space for message status.
+	     * If so, then add space for an additional 100 messages.
+	     */
+	    if (msgnum >= mp->hghoff
+		&& !(mp = folder_realloc (mp, mp->lowoff, mp->hghoff + 100))) {
+		advise (NULL, "unable to allocate folder storage");
+		i = NOTOK;
+		break;
 	    }
 
 #if 0
@@ -710,13 +719,11 @@ main (int argc, char **argv)
 		break;
 
 	    case SCNNUM: 
-		advise (NULL,
-			"more than %d messages in folder %s, %s not zero'd",
-			MAXFOLDER, folder, newmail);
+		advise (NULL, "BUG in %s, number out of range", invo_name);
 		break;
 
 	    default: 
-		advise (NULL, "scan() botch (%d)", i);
+		advise (NULL, "BUG in %s, scan() botch (%d)", invo_name, i);
 		break;
 
 	    case SCNMSG:
@@ -747,7 +754,6 @@ main (int argc, char **argv)
 #else
     if (i < 0) {		/* error */
 #endif
-
 	if (locked) {
 #ifdef MAILGROUP
 	    /* Be sure we can unlock mail file */
