@@ -449,11 +449,12 @@ mhl (int argc, char **argv)
 
     mhl_format (form ? form : mhlformat, length, width);
 
-    if (vecp == 0)
+    if (vecp == 0) {
 	process (folder, NULL, 1, vecp = 1);
-    else
+    } else {
 	for (i = 0; i < vecp; i++)
 	    process (folder, files[i], i + 1, vecp);
+    }
 
     if (forwall) {
 	if (digest) {
