@@ -10,11 +10,6 @@
 #include <errno.h>
 #include <signal.h>
 
-#ifdef MIME
-# define MIMEminc(a)  0
-#else
-# define MIMEminc(a) (a)
-#endif
 
 static struct swit switches[] = {
 #define	ALIASW                 0
@@ -41,10 +36,10 @@ static struct swit switches[] = {
     { "forward", 0 },
 #define	NFORWSW               11
     { "noforward", 0 },
-#define	MIMESW                12
-    { "mime", MIMEminc(-4) },
-#define	NMIMESW               13
-    { "nomime", MIMEminc(-6) },
+#define MIMESW                12
+    { "mime", 0 },
+#define NMIMESW               13
+    { "nomime", 0 },
 #define	MSGDSW                14
     { "msgid", 0 },
 #define	NMSGDSW               15
@@ -54,7 +49,7 @@ static struct swit switches[] = {
 #define	NPUSHSW               17
     { "nopush", 0 },
 #define	SPLITSW               18
-    { "split seconds", MIMEminc(-5) },
+    { "split seconds", 0 },
 #define	UNIQSW                19
     { "unique", -6 },
 #define	NUNIQSW               20
@@ -156,7 +151,7 @@ main (int argc, char **argv)
 
 		case HELPSW: 
 		    sprintf (buf, "%s [file] [switches]", invo_name);
-		    print_help (buf, switches);
+		    print_help (buf, switches, 1);
 		    done (1);
 		case VERSIONSW:
 		    print_version(invo_name);
@@ -220,16 +215,12 @@ main (int argc, char **argv)
 		    continue;
 
 		case MIMESW:
-#ifdef MIME
 		    mime++;
 		    vec[vecp++] = --cp;
-#endif
 		    continue;
 		case NMIMESW:
-#ifdef MIME
 		    mime = 0;
 		    vec[vecp++] = --cp;
-#endif
 		    continue;
 
 		case DEBUGSW: 
