@@ -10,10 +10,7 @@
 #include <setjmp.h>
 #include <signal.h>
 #include <fcntl.h>
-
-#ifdef MIME
-# include <h/mhn.h>
-#endif
+#include <h/mhn.h>
 
 int debugsw = 0;		/* global */
 int forwsw = 1;
@@ -38,16 +35,17 @@ static int tmp_fd (void);
 static void anno (int, struct stat *);
 static void annoaux (int);
 static int sendaux (char **, int, char *, struct stat *);
-
-#ifdef MIME
 static int sendaux2 (char **, int, char *, struct stat *);
-#endif
 
 int sendsbr (char **, int, char *, struct stat *);
 void done (int);
 char *getusr();
 
 
+/*
+ * Main entry point into routines to send message.
+ */
+
 int
 sendsbr (char **vec, int vecp, char *drft, struct stat *st)
 {
@@ -71,8 +69,6 @@ sendsbr (char **vec, int vecp, char *drft, struct stat *st)
 }
 
 
-#ifdef MIME
-
 static int
 sendaux (char **vec, int vecp, char *drft, struct stat *st)
 {
@@ -88,7 +84,7 @@ sendaux (char **vec, int vecp, char *drft, struct stat *st)
 	    || distfile
 	    || stat (drft, &sts) == NOTOK
 	    || sts.st_size < CPERMSG) {
-one_shot: ;
+one_shot:
 	splitsw = -1;
 	return sendaux2 (vec, vecp, drft, st);
     }
@@ -105,14 +101,13 @@ one_shot: ;
 	    case FLDEOF:
 	        compnum++;
 
-		if (uleq (name, VRSN_FIELD)
-		        || uleq (name, "Encrypted")
-		        || uleq (name, "Message-ID")) {
+		if (!strcasecmp (name, VRSN_FIELD)
+		        || !strcasecmp (name, "Encrypted")
+		        || !strcasecmp (name, "Message-ID")) {
 		    while (state == FLDPLUS)
 			state = m_getfld (state, name, buffer, sizeof buffer,
 					  in);
-		}
-		else
+		} else {
 		    if (uprf (name, XXX_FIELD_PRF)) {
 			dp = add (concat (name, ":", buffer, NULL), dp);
 			while (state == FLDPLUS) {
@@ -120,8 +115,7 @@ one_shot: ;
 					      sizeof buffer, in);
 			    dp = add (buffer, dp);
 			}
-		    }
-		    else {
+		    } else {
 			cp = add (concat (name, ":", buffer, NULL), cp);
 			while (state == FLDPLUS) {
 			    state = m_getfld (state, name, buffer,
@@ -129,11 +123,13 @@ one_shot: ;
 			    cp = add (buffer, cp);
 			}
 		    }
+		}
 		if (state != FLDEOF) {
 		    start = ftell (in) + 1;
 		    continue;
 		}
 		/* else fall... */
+
 	   case BODY:
 	   case BODYEOF:
 	   case FILEEOF:
@@ -268,16 +264,15 @@ one_shot: ;
 
     return status;
 }
-#endif  /* MIME */
 
 
-#ifdef MIME
+/*
+ * Annotate original message, and
+ * call `postproc' to send message.
+ */
+
 static int
 sendaux2 (char **vec, int vecp, char *drft, struct stat *st)
-#else
-static int
-sendaux (char **vec, int vecp, char *drft, struct stat *st)
-#endif
 {
     pid_t child_id;
     int i, status, fd, fd2;
@@ -309,10 +304,13 @@ sendaux (char **vec, int vecp, char *drft, struct stat *st)
     for (i = 0; (child_id = vfork()) == NOTOK && i < 5; i++)
 	sleep (5);
 
-    if (child_id == NOTOK) {
+    switch (child_id) {
+    case -1:
 	/* oops -- fork error */
 	adios ("fork", "unable to");
-    } else if (!child_id) {
+	break;	/* NOT REACHED */
+
+    case 0:
 	/*
 	 * child process -- send it
 	 *
@@ -328,34 +326,39 @@ sendaux (char **vec, int vecp, char *drft, struct stat *st)
 	fprintf (stderr, "unable to exec ");
 	perror (postproc);
 	_exit (-1);
-    }
+	break;	/* NOT REACHED */
 
-    /* parent process -- wait for it */
-    if ((status = pidwait(child_id, NOTOK)) == 0) {
+    default:
+	/*
+	 * parent process -- wait for it
+	 */
+	if ((status = pidwait(child_id, NOTOK)) == 0) {
 	    if (annotext && fd2 != NOTOK)
 		anno (fd2, st);
 	    if (splitsw < 0 &&
 	        rename (drft, strcpy (buf, m_backup (drft))) == NOTOK)
 		advise (buf, "unable to rename %s to", drft);
-    } else {
-	/*
-	 * If postproc failed, and we have good fd (which means
-	 * we pushed), then mail error message (and possibly the
-	 * draft) back to the user.
-	 */
-	if (fd != NOTOK) {
-	    alert (drft, fd);
-	    close (fd);
 	} else {
-	    advise (NULL, "message not delivered to anyone");
-	}
-	if (annotext && fd2 != NOTOK)
-	    close (fd2);
-	if (distfile) {
-	    unlink (drft);
-	    if (rename (backup, drft) == NOTOK)
-		advise (drft, "unable to rename %s to", backup);
+	    /*
+	     * If postproc failed, and we have good fd (which means
+	     * we pushed), then mail error message (and possibly the
+	     * draft) back to the user.
+	     */
+	    if (fd != NOTOK) {
+		alert (drft, fd);
+		close (fd);
+	    } else {
+		advise (NULL, "message not delivered to anyone");
+	    }
+	    if (annotext && fd2 != NOTOK)
+		close (fd2);
+	    if (distfile) {
+		unlink (drft);
+		if (rename (backup, drft) == NOTOK)
+		    advise (drft, "unable to rename %s to", backup);
+	    }
 	}
+	break;
     }
 
     return status;
